import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/loyalty_program.dart';

part 'loyalty_program_api.jretro.dart';

@GenApiClient()
class LoyaltyProgramApi extends ApiClient with _$LoyaltyProgramApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    LoyaltyProgramApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Loyaltyprogram
    ///
    /// Create Loyaltyprogram
    @PostReq(path: "/loyalty-program", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<LoyaltyProgram> createLoyaltyprogram(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() LoyaltyProgram body
        ) {
        return super.createLoyaltyprogram(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Loyaltyprogram By ID
    ///
    /// Delete Loyaltyprogram By ID
    @DeleteReq(path: "/loyalty-program/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteLoyaltyprogramByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteLoyaltyprogramByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Loyaltyprogram List
    ///
    /// Get Loyaltyprogram  List
    @GetReq(path: "/loyalty-program", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<LoyaltyProgram>> findLoyaltyprogram(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findLoyaltyprogram(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Loyaltyprogram By ID
    ///
    /// Get Loyaltyprogram By ID
    @GetReq(path: "/loyalty-program/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<LoyaltyProgram> getLoyaltyprogramByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getLoyaltyprogramByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Loyaltyprogram By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/loyalty-program/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<LoyaltyProgram> updateLoyaltyprogramByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() LoyaltyProgram body
        ) {
        return super.updateLoyaltyprogramByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}
