import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/order.dart';

part 'order_api.jretro.dart';

@GenApiClient()
class OrderApi extends ApiClient with _$OrderApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    OrderApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Order
    ///
    /// Create Order
    @PostReq(path: "/order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Order> createOrder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Order body
        ) {
        return super.createOrder(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Order By ID
    ///
    /// Delete Order By ID
    @DeleteReq(path: "/order/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteOrderByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteOrderByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Order List
    ///
    /// Get Order  List
    @GetReq(path: "/order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Order>> findOrder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findOrder(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Order By ID
    ///
    /// Get Order By ID
    @GetReq(path: "/order/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Order> getOrderByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getOrderByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Order By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/order/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Order> updateOrderByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Order body
        ) {
        return super.updateOrderByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}
